@@ -3,10 +3,14 @@
 # Copyright (C) 2012  VT SuperDARN Lab
 # Modifications:
 # 2022-03-08: MTS - added partial records exception
-# 2021-03-18: CJM - Included contour plotting and HMB
-# 2021-03-31: CJM - Map info included
-# 2021-03-31: CJM - IMF clock angle dial added
-# 2021-04-01: CJM - Bug fix for lon shifting to MLT
+# 2022-03-18: CJM - Included contour plotting and HMB
+# 2022-03-31: CJM - Map info included
+# 2022-03-31: CJM - IMF clock angle dial added
+# 2022-04-01: CJM - Bug fix for lon shifting to MLT
+# 2022-04-28: CJM - Added option to have single color vectors with reference
+#                   vector
+# 2022-08-15: CJM - Removed plot_FOV call for default uses
+# 2022-12-13: CJM - Limited reference vectors to only velocity use
 #
 # Disclaimer:
 # pyDARN is under the LGPL v3 license found in the root directory LICENSE.md
@@ -29,7 +33,7 @@ import warnings
 
 from enum import Enum
 from matplotlib import ticker, cm, colors
-from mpl_toolkits.axes_grid.inset_locator import InsetPosition
+from mpl_toolkits.axes_grid1.inset_locator import InsetPosition
 from scipy import special
 from typing import List
 
@@ -38,7 +42,7 @@ import aacgmv2
 
 from pydarn import (PyDARNColormaps, plot_exceptions,
                     standard_warning_format, Re, Hemisphere,
-                    time2datetime, find_record, Fan, MapParams)
+                    time2datetime, find_record, Fan, Projs, MapParams)
 
 warnings.formatwarning = standard_warning_format
 
@@ -64,12 +68,14 @@ class Maps():
                      parameter: Enum = MapParams.FITTED_VELOCITY,
                      record: int = 0, start_time: dt.datetime = None,
                      time_delta: float = 1,  alpha: float = 1.0,
-                     len_factor: float = 150, cmap: str = None,
-                     colorbar: bool = True, colorbar_label: str = '',
-                     title: str = '', zmin: float = None, zmax: float = None,
+                     len_factor: float = 150, color_vectors: bool = True,
+                     cmap: str = None, colorbar: bool = True,
+                     colorbar_label: str = '', title: str = '',
+                     zmin: float = None, zmax: float = None,
                      hmb: bool = True, boundary: bool = False,
                      radar_location: bool = False, map_info: bool = True,
-                     imf_dial: bool = True, **kwargs):
+                     imf_dial: bool = True, reference_vector: int = 500,
+                     projs: Projs = Projs.POLAR, **kwargs):
         """
         Plots convection maps data points and vectors
 
@@ -93,6 +99,10 @@ class Maps():
                 How close the start_time has to be start_time of the record
                 in minutes
                 default: 1
+            color_vectors: bool
+                If True, color the vectors by color map chosen
+                If False, color dark grey and include vector reference
+                Default: True
             cmap: matplotlib.cm
                 matplotlib colour map
                 https://matplotlib.org/tutorials/colors/colormaps.html
@@ -134,6 +144,16 @@ class Maps():
             imf_dial: bool
                 If True, draw an IMF dial of the magnetic field clock angle.
                 Default: True
+            reference_vector: int
+                If a value is given, a reference velocity vector with
+                magnitude of given value, drawn in lower right corner.
+                Vector can be turned off by setting this value to False or 0.
+                Will not plot for power or spectral width options.
+                Default: 500 (vector plotted)
+            projs: Enum
+                choice of projection for plot
+                default: Projs.POLAR (polar projection)
+                There is no support for other projections currently
             kwargs: key=value
                 uses the parameters for plot_fov and projections.axis
 
@@ -142,6 +162,7 @@ class Maps():
         if start_time is not None:
             record = find_record(dmap_data, start_time, time_delta)
         date = time2datetime(dmap_data[record])
+
         if cmap is None:
             cmap = {MapParams.FITTED_VELOCITY: 'plasma_r',
                     MapParams.MODEL_VELOCITY: 'plasma_r',
@@ -164,13 +185,27 @@ class Maps():
         norm = colors.Normalize
         norm = norm(zmin, zmax)
 
+        if projs != Projs.POLAR:
+            raise plot_exceptions.NotImplemented(" Only polar projections"
+                                                 " are implemented for"
+                                                 " convection maps."
+                                                 " Please set"
+                                                 " projs=Projs.POLAR"
+                                                 " to plot a convection map.")
+
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            # TODO: Make FOV outlines optional or invisible
-            for stid in dmap_data[record]['stid']:
-                _, aacgm_lons, ax, _ =\
-                        Fan.plot_fov(stid, date, ax=ax, boundary=boundary,
-                                     radar_location=radar_location, **kwargs)
+            # If the user wants to plot a FOV boundary or radar location
+            # Needs to find the positions for each
+            # Else just call the axis maker: proj
+            if boundary or radar_location:
+                for stid in dmap_data[record]['stid']:
+                    _, _, ax, _ =\
+                            Fan.plot_fov(stid, date, ax=ax, boundary=boundary,
+                                         radar_location=radar_location,
+                                         **kwargs)
+            else:
+                ax, _ = projs(date, ax=ax, hemisphere=hemisphere, **kwargs)
 
         if parameter == MapParams.MODEL_VELOCITY:
             try:
@@ -185,12 +220,11 @@ class Maps():
             except KeyError:
                 raise plot_exceptions.PartialRecordsError('model.mlat')
 
-        # Hold the beam positions
-        shifted_mlts = aacgm_lons[0, 0] - \
-            (aacgmv2.convert_mlt(aacgm_lons[0, 0], date) * 15)
+        # Arbitrary lon used to calculate the shift required
+        shifted_mlts = 0 - (aacgmv2.convert_mlt(0, date) * 15)
         shifted_lons = data_lons - shifted_mlts
         # Note that this "mlons" is adjusted for MLT
-        mlons = np.radians(shifted_lons) 
+        mlons = np.radians(shifted_lons)
         mlats = data_lats
 
         # If the parameter is velocity then plot the LOS vectors
@@ -208,6 +242,7 @@ class Maps():
                                                      lat_min=dmap_data[
                                                          record]['latmin'],
                                                      len_factor=len_factor)
+
         elif parameter == MapParams.MODEL_VELOCITY:
             v_mag = dmap_data[record]['model.vel.median']
             azm_v = np.radians(dmap_data[record]['model.kvect'])
@@ -224,9 +259,21 @@ class Maps():
 
         if parameter in [MapParams.FITTED_VELOCITY, MapParams.MODEL_VELOCITY,
                          MapParams.RAW_VELOCITY]:
+            # Make reference vector and add it to the array to
+            # be calculated too
+            reflat = (np.abs(plt.gca().get_ylim()[1]) - 5) * hemisphere.value
+            reflon = np.radians(45)
+            v_mag = np.append(v_mag, reference_vector)
+            if hemisphere == Hemisphere.North:
+                azm_v = np.append(azm_v, np.radians(135))
+            else:
+                azm_v = np.append(azm_v, np.radians(45))
+
             # Angle to "rotate" each vector by to get into same
             # reference frame Controlled by longitude, or "mltitude"
-            alpha = mlons
+            alpha = np.append(mlons, reflon)
+            mlons = np.append(mlons, reflon)
+            mlats = np.append(mlats, reflat)
 
             # Convert initial positions to Cartesian
             start_pos_x = (90 - abs(mlats)) * np.cos(mlons)
@@ -245,48 +292,82 @@ class Maps():
             vec_y = (x * np.sin(alpha)) + (y * np.cos(alpha))
 
             # New vector end points, in Cartesian
-            end_pos_x = start_pos_x + (vec_x  * hemisphere.value / len_factor)
-            end_pos_y = start_pos_y + (vec_y  * hemisphere.value / len_factor)
+            end_pos_x = start_pos_x + (vec_x * hemisphere.value / len_factor)
+            end_pos_y = start_pos_y + (vec_y * hemisphere.value / len_factor)
 
             # Convert back to polar for plotting
             end_mlats = 90.0 - (np.sqrt(end_pos_x**2 + end_pos_y**2))
             end_mlons = np.arctan2(end_pos_y, end_pos_x)
-            
-            end_mlats=end_mlats * hemisphere.value
 
-            # Plot the vectomlats
-            for i in range(len(v_mag)):
-                plt.plot([mlons[i], end_mlons[i]],
-                         [mlats[i], end_mlats[i]], c=cmap(norm(v_mag[i])),
-                         linewidth=0.5, zorder=5.0)
-        plt.scatter(mlons, mlats, c=v_mag, s=2.0,
-                    vmin=zmin, vmax=zmax,  cmap=cmap, zorder=5.0)
+            end_mlats = end_mlats * hemisphere.value
 
-        # Plot potential contours
-        fit_coefficient = dmap_data[record]['N+2']
-        fit_order = dmap_data[record]['fit.order']
-        lat_shift = dmap_data[record]['lat.shft']
-        lon_shift = dmap_data[record]['lon.shft']
-        lat_min = dmap_data[record]['latmin']
+            # Plot the vector socks (final vector is the reference
+            # vector to be plotted later if required)
+            if color_vectors is True:
+                for i in range(len(v_mag) - 1):
+                    plt.plot([mlons[i], end_mlons[i]],
+                             [mlats[i], end_mlats[i]], c=cmap(norm(v_mag[i])),
+                             linewidth=0.5, zorder=5.0)
+            else:
+                for i in range(len(v_mag) - 1):
+                    plt.plot([mlons[i], end_mlons[i]],
+                             [mlats[i], end_mlats[i]], c='#292929',
+                             linewidth=0.5, zorder=5.0)
 
-        cls.plot_potential_contours(fit_coefficient, lat_min, date,
-                                    lat_shift=lat_shift, lon_shift=lon_shift,
-                                    fit_order=fit_order, hemisphere=hemisphere,
-                                    **kwargs)
+        # Plot the sock start dots and reference vector if known
+        if color_vectors is True:
+            if parameter in [MapParams.FITTED_VELOCITY,
+                             MapParams.MODEL_VELOCITY,
+                             MapParams.RAW_VELOCITY]:
+                if reference_vector > 0:
+                    plt.scatter(mlons[:], mlats[:], c=v_mag[:], s=2.0,
+                                vmin=zmin, vmax=zmax,  cmap=cmap, zorder=5.0,
+                                clip_on=False)
+                    plt.plot([mlons[-1], end_mlons[-1]],
+                             [mlats[-1], end_mlats[-1]], c=cmap(norm(v_mag[-1])),
+                             linewidth=0.5, zorder=5.0, clip_on=False)
+                    plt.figtext(0.675, 0.15, str(reference_vector) + ' m/s',
+                                fontsize=8)
+                else:
+                    plt.scatter(mlons[:-1], mlats[:-1], c=v_mag[:-1], s=2.0,
+                                vmin=zmin, vmax=zmax,  cmap=cmap, zorder=5.0)
+            else:
+                plt.scatter(mlons[:], mlats[:], c=v_mag[:], s=2.0,
+                            vmin=zmin, vmax=zmax,  cmap=cmap, zorder=5.0)
 
-        if hmb is True:
-            # Plot the HMB
-            mlats_hmb = dmap_data[record]['boundary.mlat']
-            mlons_hmb = dmap_data[record]['boundary.mlon']
-            cls.plot_heppner_maynard_boundary(mlats_hmb, mlons_hmb, date)
+        else:
+            # no color so make sure colorbar is turned off
+            colorbar = False
+            if parameter in [MapParams.FITTED_VELOCITY,
+                             MapParams.MODEL_VELOCITY,
+                             MapParams.RAW_VELOCITY]:
+                if reference_vector > 0:
+                    plt.scatter(mlons[:], mlats[:], c='#292929', s=2.0,
+                                zorder=5.0, clip_on=False)
+                    plt.plot([mlons[-1], end_mlons[-1]],
+                             [mlats[-1], end_mlats[-1]], c='#292929',
+                             linewidth=0.5, zorder=5.0, clip_on=False)
+                    plt.figtext(0.675, 0.15, str(reference_vector) + ' m/s',
+                                fontsize=8)
+                else:
+                    plt.scatter(mlons[:-1], mlats[:-1], c='#292929', s=2.0,
+                                zorder=5.0)
+            else:
+                plt.scatter(mlons[:], mlats[:], c='#292929', s=2.0,
+                                zorder=5.0)
 
         if colorbar is True:
             mappable = cm.ScalarMappable(norm=norm, cmap=cmap)
             locator = ticker.MaxNLocator(symmetric=True, min_n_ticks=3,
                                          integer=True, nbins='auto')
             ticks = locator.tick_values(vmin=zmin, vmax=zmax)
-            cb = ax.figure.colorbar(mappable, ax=ax,
-                                    extend='both', ticks=ticks)
+
+            if zmin == 0:
+                cb = ax.figure.colorbar(mappable, ax=ax, extend='max',
+                                        ticks=ticks)
+            else:
+                cb = ax.figure.colorbar(mappable, ax=ax, extend='both',
+                                        ticks=ticks)
 
             if colorbar_label != '':
                 cb.set_label(colorbar_label)
@@ -300,6 +381,24 @@ class Maps():
                 elif parameter is MapParams.POWER:
                     cb.set_label('Power')
 
+        # Plot potential contours
+        fit_coefficient = dmap_data[record]['N+2']
+        fit_order = dmap_data[record]['fit.order']
+        lat_shift = dmap_data[record]['lat.shft']
+        lon_shift = dmap_data[record]['lon.shft']
+        lat_min = dmap_data[record]['latmin']
+
+        cls.plot_potential_contours(fit_coefficient, lat_min, date, ax,
+                                    lat_shift=lat_shift, lon_shift=lon_shift,
+                                    fit_order=fit_order, hemisphere=hemisphere,
+                                    **kwargs)
+
+        if hmb is True:
+            # Plot the HMB
+            mlats_hmb = dmap_data[record]['boundary.mlat']
+            mlons_hmb = dmap_data[record]['boundary.mlon']
+            cls.plot_heppner_maynard_boundary(mlats_hmb, mlons_hmb, date)
+
         if title == '':
             title = "{year}-{month}-{day} {start_hour}:{start_minute} -"\
                 " {end_hour}:{end_minute}"\
@@ -583,7 +682,7 @@ class Maps():
 
 
     @classmethod
-    def plot_heppner_maynard_boundary(cls, mlats: list, mlons: list, 
+    def plot_heppner_maynard_boundary(cls, mlats: list, mlons: list,
                                       date: object, line_color: str = 'black',
                                       **kwargs):
         # TODO: No evaluation of coordinate system made! May need if in
@@ -735,7 +834,6 @@ class Maps():
         # Adjusted/Normalised values (runs 0 - pi)
         alpha = np.pi / theta_max
         x = np.cos(alpha*theta)
-
         # Legendre Polys
         for j, xj in enumerate(x):
             plm_tmp = special.lpmn(fit_order, fit_order, xj)
@@ -783,7 +881,7 @@ class Maps():
 
     @classmethod
     def plot_potential_contours(cls, fit_coefficient: list, lat_min: list,
-                                date: object, lat_shift: int = 0,
+                                date: object, ax: object, lat_shift: int = 0,
                                 lon_shift: int = 0, fit_order: int = 6,
                                 hemisphere: Enum = Hemisphere.North,
                                 contour_levels: list = [],
@@ -809,6 +907,8 @@ class Maps():
                 Not to be confused with 'lowlat'
             date: datetime object
                 Date from record
+            ax: object
+                matplotlib axis object
             lat_shift: int
                 Generic shift in latitude from map file
                 default: 0
@@ -888,7 +988,7 @@ class Maps():
                          vmax=abs(pot_arr).max(),
                          vmin=-abs(pot_arr).max(),
                          locator=ticker.FixedLocator(contour_levels),
-                         cmap=contour_fill_cmap, alpha=0.6,
+                         cmap=contour_fill_cmap, alpha=0.5,
                          extend='both', zorder=3.0)
             if contour_colorbar is True:
                 norm = colors.Normalize
@@ -898,7 +998,7 @@ class Maps():
                                              integer=True, nbins='auto')
                 ticks = locator.tick_values(vmin=-abs(pot_arr).max(),
                                             vmax=abs(pot_arr).max())
-                cb = plt.colorbar(mappable, extend='both', ticks=ticks)
+                cb = plt.colorbar(mappable, ax=ax, extend='both', ticks=ticks)
                 if contour_colorbar_label != '':
                     cb.set_label(contour_colorbar_label)
         else:
